CREATE DATABASE base_prueba
GO

USE base_prueba
GO

CREATE TABLE cat_articulos
(
	art_cve_art		CHAR(15)			NOT NULL,
	art_descripcion	CHAR(70)			NOT NULL,
	art_precio			DECIMAL(11,3)	NOT NULL,
	art_tipo_mon		CHAR(3)			NOT NULL,
	art_status			CHAR(1)				NOT NULL DEFAULT 'N',
	art_cost_prom	DECIMAL(11,3)	NOT NULL DEFAULT 0.00,
	art_cost_fob		DECIMAL(11,3)	NOT NULL DEFAULT 0.00,
	art_cost_int		DECIMAL(11,3)	NOT NULL DEFAULT 0.00,
	CONSTRAINT pk_art_cve_art PRIMARY KEY (art_cve_art)
)
GO

CREATE TABLE cat_parm_gral
(
	par_cve_empresa	CHAR(2)			NOT NULL,
	par_nombre			CHAR(50)			NOT NULL,
	par_direccion			CHAR(40)			NOT NULL,
	par_ciudad				CHAR(20)			NOT NULL,
	par_estado				CHAR(20)			NOT NULL,
	par_pais				CHAR(3)			NOT NULL,
	par_rfc					CHAR(20)			NOT NULL,
	par_mon_local		CHAR(3)			NULL,
	par_cp					CHAR(5)			NULL,
	par_tel					CHAR(15)			NULL,
	par_fax					CHAR(15)			NULL,
	par_lada				INTEGER			NULL,
	par_clave				CHAR(1)			NOT NULL,
	par_sepomex				CHAR(1)			NOT NULL,
	par_contab_enlinea	CHAR(1)			NULL,
	par_usa_cta_comp	CHAR(1)			NULL DEFAULT 'N',
	CONSTRAINT cat_parm_g_1085274201 PRIMARY KEY clustered (par_cve_empresa)
)
GO

CREATE TABLE cat_rec_humanos
(
	hum_num_emp		NUMERIC(7)		NOT NULL,
	hum_ape_pat		CHAR(20)			NOT NULL,
	hum_ape_mat		CHAR(20)			NOT NULL,
	hum_nombre		CHAR(15)			NOT NULL,
	hum_fec_alta		DATETIME		NOT NULL,
	hum_fec_baja		DATETIME		NULL,
	CONSTRAINT pk_cat_rec_humanos PRIMARY KEY clustered (hum_num_emp)
)
GO

CREATE TABLE mov_existencia
(
	exi_cve_art		CHAR(15)			NOT NULL,
	exi_num_alm		TINYINT			NOT NULL,
	exi_existencia	INTEGER			NOT NULL,
	exi_disponible	INTEGER			NOT NULL,
	exi_apartado		INTEGER			NOT NULL,
	exi_fecha			DATETIME		NOT NULL,
	CONSTRAINT ctp_existencia PRIMARY KEY clustered (exi_cve_art, exi_num_alm)
)
GO

CREATE TABLE prod_art_vs_proceso
(
	prod_avsp_cve_art						CHAR(15)			NOT NULL,
	prod_avsp_tipo_material				CHAR(2)			NOT NULL
	CONSTRAINT ckc_prod_avsp_tipo_ma_prod_art CHECK (prod_avsp_tipo_material IN ('PT','CO','IN')),
	prod_avsp_id_unidad					SMALLINT		NOT NULL,
	prod_avsp_id_proc						NUMERIC(7,0)	NOT NULL,
	prod_avsp_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_avsp_fec_alta						DATETIME		NOT NULL,
	prod_avsp_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_avsp_fec_bajamodif			DATETIME		NULL,
	prod_avsp_status						CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_avsp_status_prod_art CHECK (prod_avsp_status IN ('H','D')),
	prod_avsp_observaciones				CHAR(255)			NULL,
	CONSTRAINT pk_prod_art_vs_proceso PRIMARY KEY  (prod_avsp_cve_art, prod_avsp_tipo_material)
)
GO

CREATE TABLE prod_avance_orden_prod
(
	prod_aop_op_folio				NUMERIC(7,0)	NOT NULL,
	prod_aop_as_folio				NUMERIC(7,0)	NOT NULL,
	prod_aop_cve_art				CHAR(15)			NOT NULL,
	prod_aop_cantidad				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_aop_num_emp				NUMERIC(7,0)	NOT NULL,
	prod_aop_fecha					DATETIME		NULL,
	prod_aop_observaciones	TEXT						NULL,
	CONSTRAINT pk_prod_avance_orden_prod PRIMARY KEY  (prod_aop_op_folio, prod_aop_as_folio)
)
GO

CREATE TABLE prod_bas_bit_cambio_materiales
(
	prod_bbc_id						NUMERIC(7,0)		NOT NULL,
	prod_bbc_orig_id				NUMERIC(7,0)         NOT NULL,
	prod_bbc_cve_padre			CHAR(15)				NOT NULL,
	prod_bbc_cve_hijo				CHAR(15)				NOT NULL,
	prod_bbc_cve_hijo_ant		CHAR(15)				NOT NULL,
	prod_bbc_tipo_material_ant	CHAR(2)				NOT NULL
	CONSTRAINT ckc_prod_bbc_tipo_mat_prod_bas CHECK (prod_bbc_tipo_material_ant IN ('PT','CO','IN')),
	prod_bbc_cantidad_ant		DECIMAL(11,3)		NOT NULL,
	prod_bbc_id_unidad_ant		SMALLINT			NOT NULL,
	prod_bbc_num_emp				NUMERIC(7,0)		NOT NULL,
	prod_bbc_fec						DATETIME			NOT NULL,
	prod_bbc_observaciones		CHAR(250)				NOT NULL,
	CONSTRAINT pk_prod_bas_bit_cambio_materia PRIMARY KEY  (prod_bbc_orig_id)
)
GO

CREATE TABLE prod_bas_exp_materiales
(
	prod_bem_id								NUMERIC(7,0)	IDENTITY,
	prod_bem_cve_padre					CHAR(15)			NOT NULL,
	prod_bem_cve_hijo						CHAR(15)			NOT NULL,
	prod_bem_tipo_material				CHAR(2)			NOT NULL
	CONSTRAINT ckc_prod_bem_tipo_mat_prod_bas CHECK (prod_bem_tipo_material IN ('PT','IN','CO')),
	prod_bem_opcional_de					CHAR(15)			NOT NULL,
	prod_bem_cantidad						DECIMAL(11,3)	NOT NULL,
	prod_bem_id_unidad					SMALLINT		NOT NULL,
	prod_bem_importancia					CHAR(1)				NOT NULL
	CONSTRAINT ckc_prod_bem_importan_prod_bas CHECK (prod_bem_importancia IN ('P','O')),
	prod_bem_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_bem_fec_alta						DATETIME		NOT NULL,
	prod_bem_num_emp_bajamodif		NUMERIC(7,0)	NOT NULL,
	prod_bem_fec_bajamodif				DATETIME		NOT NULL,
	prod_bem_status							CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_bem_status_prod_bas CHECK (prod_bem_status IN ('H','D','E')),
	prod_bem_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_bas_exp_materiales PRIMARY KEY  (prod_bem_id)
)
GO

CREATE TABLE prod_bit_cambio_materiales
(
	prod_bcc_id						NUMERIC(7,0)	IDENTITY,
	prod_bcc_cve_padre			CHAR(15)			NOT NULL,
	prod_bcc_cve_hijo				CHAR(15)			NOT NULL,
	prod_bcc_cve_hijo_ant		CHAR(15)			NOT NULL,
	prd_bcc_tipo_material_ant	CHAR(2)			NOT NULL
	CONSTRAINT ckc_prd_bcc_tipo_mate_prod_bit CHECK (prd_bcc_tipo_material_ant IN ('PT','CO','IN')),
	prod_bcc_cantidad_ant		DECIMAL(11,3)	NOT NULL,
	prod_bcc_id_unidad_ant		SMALLINT		NOT NULL,
	prod_bcc_num_emp				NUMERIC(7,0)	NOT NULL,
	prod_bcc_fec						DATETIME		NOT NULL,
	prod_bcc_observaciones		CHAR(250)			NOT NULL,
	CONSTRAINT pk_prod_bit_cambio_materiales PRIMARY KEY (prod_bcc_id)
)
GO

CREATE TABLE prod_bit_orden_prod
(
	prod_bop_op_folio			NUMERIC(7,0)	NOT NULL,
	prod_bop_op_folio_bit	NUMERIC(7,0)	NOT NULL,
	prod_bop_id_estado		SMALLINT		NOT NULL,
	prod_bop_num_emp			NUMERIC(7,0)	NOT NULL,
	prod_bop_fecha				DATETIME		NOT NULL,
	prod_bop_observaciones	CHAR(250)			NULL,
	CONSTRAINT pk_prod_bit_orden_prod PRIMARY KEY  (prod_bop_op_folio, prod_bop_op_folio_bit)
)
GO

CREATE TABLE prod_bit_plan_prod
(
	prod_bpp_id						NUMERIC(7,0)	IDENTITY,
	prod_bpp_periodo				CHAR(6)			NOT NULL,
	prod_bpp_cve_prod_final	CHAR(15)			NOT NULL,
	prod_bpp_dia						CHAR(2)			NOT NULL,
	prod_bpp_cantactual			DECIMAL(11,3)	NOT NULL,
	prod_bpp_cantant				DECIMAL(11,3)	NOT NULL,
	prod_bpp_num_emp				NUMERIC(7,0)	NOT NULL,
	prod_bpp_fecha					DATETIME		NOT NULL,
	prod_bpp_observaciones		CHAR(250)			NULL,
	CONSTRAINT pk_prod_bit_plan_prod PRIMARY KEY (prod_bpp_id)
)
GO

CREATE TABLE prod_cat_estados_op
(
	prod_cat_eop_id_status				SMALLINT		NOT NULL,
	prod_cat_eop_descripcion			CHAR(50)			NOT NULL,
	prod_cat_eop_equivalente			CHAR(50)			NOT NULL,
	prod_cat_eop_num_emp_alta		NUMERIC(7,0)	NOT NULL,
	prod_cat_eop_fecha_alta				DATETIME		NOT NULL,
	prod_cat_eop_num_emp_modif		NUMERIC(7,0)	NULL,
	prod_cat_eop_fecha_modif			DATETIME		NULL,
	prod_cat_eop_observaciones		CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_estados_op PRIMARY KEY (prod_cat_eop_id_status)
)
GO

CREATE TABLE prod_cat_fases_prod
(
	prod_cat_fp_id_fase						NUMERIC(7,0)	NOT NULL,
	prod_cat_fp_descripcion					CHAR(250)			NOT NULL,
	prod_cat_fp_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_cat_fp_fec_alta						DATETIME		NOT NULL,
	prod_cat_fp_num_emp_bajamodif		NUMERIC(7,0)	NULL,
	prod_cat_fp_fec_bajamodif				DATETIME		NULL,
	prod_cat_fp_status							CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_cat_fp_statu_prod_cat CHECK (prod_cat_fp_status IN ('H','D')),
	prod_cat_fp_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_fases_prod PRIMARY KEY (prod_cat_fp_id_fase)
)
GO

CREATE TABLE prod_cat_lineas_ensamble
(
	prod_cat_le_id_linea_ens				SMALLINT		NOT NULL,
	prod_cat_le_descripcion					CHAR(50)			NOT NULL,
	prod_cat_le_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_cat_le_fecha_alta					DATETIME		NOT NULL,
	prod_cat_le_num_emp_bajamodif		 NUMERIC(7,0)	NULL,
	prod_cat_le_fecha_bajamodif			DATETIME		NULL,
	prod_cat_le_status							CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_cat_le_statu_prod_cat CHECK (prod_cat_le_status IN ('H','D')),
	prod_cat_le_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_lineas_ensamble PRIMARY KEY (prod_cat_le_id_linea_ens)
)
GO

CREATE TABLE prod_cat_mot_tiempos_muertos
(
	prod_cat_mtm_id_motivo					NUMERIC(7,0)	NOT NULL,
	prod_cat_mtm_descripcion				CHAR(250)			NOT NULL,
	prod_cat_mtm_num_emp_alta			NUMERIC(7,0)	NOT NULL,
	prod_cat_mtm_fec_alta					DATETIME		NOT NULL,
	prod_cat_mtm_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_cat_mtm_fec_bajamodifi			DATETIME		NULL,
	prod_cat_mtm_status						CHAR(1)				NOT NULL,
	por_cat_mtm_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_mot_tiempos_muerto PRIMARY KEY (prod_cat_mtm_id_motivo)
)
GO

CREATE TABLE prod_cat_proc_prod
(
	prod_cat_pp_id_proc						NUMERIC(7,0)	NOT NULL,
	prod_cat_pp_descripcion					CHAR(250)			NOT NULL,
	prod_cat_pp_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_cat_pp_fecha_alta					DATETIME		NOT NULL,
	prod_cat_pp_num_emp_bajamodif		NUMERIC(7,0)	NULL,
	prod_cat_pp_fecha_bajamodif			DATETIME		NULL,
	prod_cat_pp_status							CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_cat_pp_statu_prod_cat CHECK (prod_cat_pp_status IN ('H','D')),
	prod_cat_pp_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_proc_prod PRIMARY KEY (prod_cat_pp_id_proc)
)
GO

CREATE TABLE prod_cat_tipos_prod
(
	prod_cat_tp_clave						CHAR(2)			NOT NULL,
	prod_cat_tp_descripcion				CHAR(250)			NOT NULL,
	prod_cat_tp_num_emp_alta			NUMERIC(7,0)	NOT NULL,
	prod_cat_tp_fecha_alta				DATETIME		NOT NULL,
	prod_cat_tp_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_cat_tp_fec_bajamodif			DATETIME		NULL,
	prod_cat_tp_status						CHAR(1)				NULL
	CONSTRAINT ckc_prod_cat_tp_statu_prod_cat CHECK (prod_cat_tp_status is NULL or ( prod_cat_tp_status IN ('H','D') )),
	prod_cat_tp_observaciones			CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_tipos_prod PRIMARY KEY (prod_cat_tp_clave)
)
GO

CREATE TABLE prod_cat_turnos
(
	prod_cat_t_id_turno					SMALLINT		NOT NULL,
	prod_cat_t_descripcion				CHAR(30)			NOT NULL,
	prod_cat_t_cant_empledos			NUMERIC(7,0)	NOT NULL,
	prod_cat_t_hora_inicio				DATETIME		NULL,
	prod_cat_t_hora_fin					DATETIME		NULL,
	prod_cat_t_num_emp_alta			NUMERIC(7,0)	NOT NULL,
	prod_cat_t_fec_alta					DATETIME		NOT NULL,
	prod_cat_t_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_cat_t_fec_bajamod				DATETIME		NULL,
	prod_cat_t_status						CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_cat_t_status_prod_cat CHECK (prod_cat_t_status IN ('H','D')),
	prod_cat_t_observaciones 			CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_turnos PRIMARY KEY (prod_cat_t_id_turno)
)
GO

CREATE TABLE prod_cat_unidades_medida
(
	prod_cat_um_id_unidad					SMALLINT		NOT NULL,
	prod_cat_um_cve_unidad					CHAR(3)			NOT NULL,
	prod_cat_um_descripcion					CHAR(30)			NOT NULL,
	prod_cat_um_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_cat_um_fec_alta						DATETIME		NOT NULL,
	prod_cat_um_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_cat_um_fec_bajamodif			DATETIME		NULL,
	prod_cat_um_status							CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_cat_um_statu_prod_cat CHECK (prod_cat_um_status IN ('H','D')),
	prod_cat_um_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_cat_unidades_medida PRIMARY KEY (prod_cat_um_id_unidad)
)
GO

CREATE TABLE prod_depend_fases
(
	prod_df_id_proc						NUMERIC(7,0)	NOT NULL,
	prod_df_id_fasey					NUMERIC(7,0)	NOT NULL,
	prod_df_id_fasex					NUMERIC(7,0)	NOT NULL,
	prod_df_porcentaje					TINYINT			NOT NULL,
	prod_df_num_emp_alta			NUMERIC(7,0)	NOT NULL,
	prod_df_fec_alta					DATETIME		NOT NULL,
	prod_df_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_df_fec_bajamodif			DATETIME		NULL,
	prod_df_status						CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_df_status_prod_dep CHECK (prod_df_status IN ('H','D')),
	prod_df_observaciones			CHAR(250)			NULL,
	CONSTRAINT pk_prod_depend_fases PRIMARY KEY (prod_df_id_proc, prod_df_id_fasey, prod_df_id_fasex)
)
GO

CREATE TABLE prod_det_orden_prod
(
	prod_dop_folio				NUMERIC(7,0)		NOT NULL,
	prod_dop_folio_det			NUMERIC(7,0)		NOT NULL,
	prod_dop_nivel				TINYINT				NOT NULL DEFAULT 0,
	prod_dop_cve_padre		CHAR(15)				NOT NULL,
	prod_dop_importancia		CHAR(1)					NOT NULL
	CONSTRAINT ckc_prod_dop_importan_prod_det CHECK (prod_dop_importancia IN ('P','O')),
	prod_dop_osiifo				CHAR(1)					NOT NULL DEFAULT 'I'
	CONSTRAINT ckc_prod_dop_osiifo_prod_det CHECK (prod_dop_osiifo IN ('O','S','I')),
	prod_dop_ifo					CHAR(1)					NOT NULL DEFAULT 'S'
	CONSTRAINT ckc_prod_dop_ifo_prod_det CHECK (prod_dop_ifo IN ('S','N')),
	prod_dop_cve_hijo			CHAR(15)				NOT NULL,
	prod_dop_opcionales		CHAR(1)					NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_dop_opcional_prod_det CHECK (prod_dop_opcionales IN ('S','N')),
	prod_dop_costo_unit		DECIMAL(11,3)		NOT NULL,
	prod_dop_cantidad			DECIMAL(11,3)		NOT NULL,
	prod_dop_cantmaxperm	DECIMAL(11,3)		NOT NULL,
	prod_dop_id_unidad		SMALLINT			NOT NULL,
	prod_dop_existencia		DECIMAL(11,3)		NOT NULL DEFAULT 0,
	prod_dop_cant_util			DECIMAL(11,3)		NOT NULL DEFAULT 0,
	prod_dop_observaciones	CHAR(250)				NULL,
	CONSTRAINT pk_prod_det_orden_prod PRIMARY KEY (prod_dop_folio, prod_dop_folio_det)
)
GO

CREATE TABLE prod_exp_materiales
(
	prod_em_cve_padre				CHAR(15)			NOT NULL,
	prod_em_cve_hijo					CHAR(15)			NOT NULL,
	prod_em_tipo_material			CHAR(2)			NOT NULL
	CONSTRAINT ckc_prod_em_tipo_mate_prod_exp CHECK (prod_em_tipo_material IN ('PT','IN','CO')),
	prod_em_opcional_de				CHAR(15)             NOT NULL,
	prod_em_cantidad					DECIMAL(11,3)	NOT NULL,
	prod_em_id_unidad					SMALLINT		NOT NULL,
	prod_em_importancia				CHAR(1)				NOT NULL
	CONSTRAINT ckc_prod_em_importanc_prod_exp CHECK (prod_em_importancia IN ('P','O')),
	prod_em_merma						CHAR(1)				NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_em_merma_prod_exp CHECK (prod_em_merma IN ('S','N')),
	prod_em_serializable				CHAR(1)				NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_em_serializa_prod_exp CHECK (prod_em_serializable IN ('S','N')),
	prod_em_num_emp_alta			NUMERIC(7,0)	NOT NULL,
	prod_em_fec_alta					DATETIME		NOT NULL,
	prod_em_num_emp_bajamodif	NUMERIC(7,0)	NULL,
	prod_em_fec_bajamodif			DATETIME		NULL,
	prod_em_status						CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_em_status_prod_exp CHECK (prod_em_status IN ('H','D','E')),
	prod_em_observaciones			CHAR(250)			NULL,
	CONSTRAINT pk_prod_exp_materiales PRIMARY KEY (prod_em_cve_padre, prod_em_cve_hijo, prod_em_opcional_de)
)
GO

CREATE TABLE prod_mat_adic_orden_prod
(
	prod_ma_op_folio							NUMERIC(7,0)	NOT NULL,
	prod_ma_op_folio_adic					NUMERIC(7,0)	NOT NULL,
	prod_ma_op_cve_art						CHAR(15)			NOT NULL,
	prod_ma_op_cantsolic						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_ma_op_cantsurt						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_ma_op_num_emp_alta				NUMERIC(7,0)	NOT NULL,
	prod_ma_op_fec_alta						DATETIME		NULL,
	prod_ma_op_num_emp_bajamodif		NUMERIC(7,0)	NULL,
	prod_ma_op_fec_bajamodif				DATETIME		NULL,
	prod_ma_op_status							CHAR(1)				NOT NULL DEFAULT 'G'
	CONSTRAINT ckc_prod_ma_op_status_prod_mat CHECK (prod_ma_op_status IN ('G','S','C')),
	prod_ma_op_observaciones				CHAR(250)			NULL,
	CONSTRAINT pk_prod_mat_adic_orden_prod PRIMARY KEY (prod_ma_op_folio, prod_ma_op_folio_adic)
)
GO

CREATE TABLE prod_merma_orden_prod
(
	prod_mop_op_folio			NUMERIC(7,0)	NOT NULL,
	prod_mop_as_folio			NUMERIC(7,0)	NOT NULL,
	prod_mop_cve_art			CHAR(15)			NOT NULL,
	prod_mop_cantidad			DECIMAL(11,3)	NOT NULL,
	prod_mop_num_emp			NUMERIC(7,0)	NOT NULL,
	prod_mop_fecha				DATETIME		NOT NULL,
	prod_mop_observaciones	CHAR(250)			NULL,
	CONSTRAINT pk_prod_merma_orden_prod PRIMARY KEY (prod_mop_op_folio, prod_mop_as_folio)
)
GO

CREATE TABLE prod_orden_prod
(
	prod_op_folio							NUMERIC(7,0)         NOT NULL,
	prod_op_fecha_prod				DATETIME			NULL,
	prod_op_periodo						CHAR(6)				NULL,
	prod_op_dia							SMALLINT			NULL,
	prod_op_id_turno					SMALLINT			NOT NULL,
	prod_op_id_linea_ens				SMALLINT			NOT NULL,
	prod_op_tp_clave					CHAR(2)				NOT NULL,
	prod_op_cve_prod_final			CHAR(15)				NOT NULL,
	prod_op_cantidad					DECIMAL(11,3)		NOT NULL DEFAULT 0,
	prod_op_id_unidad					SMALLINT			NOT NULL,
	prod_op_id_proc_prod				NUMERIC(7,0)		NOT NULL,
	prod_op_costo_inicial				DECIMAL(11,3)		NOT NULL,
	prod_op_costo_final				DECIMAL(11,3)		NOT NULL,
	prod_op_moneda						CHAR(3)				NOT NULL,
	prod_op_merma						CHAR(1)					NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_op_merma_prod_ord CHECK (prod_op_merma IN ('S','N')),
	prod_op_serializable				CHAR(1)					NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_op_serializa_prod_ord CHECK (prod_op_serializable IN ('S','N')),
	prod_op_lote							CHAR(50)				NULL,
	prod_op_origen_plan_prod		CHAR(1)					NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_op_origen_pl_prod_ord CHECK (prod_op_origen_plan_prod IN ('S','N')),
	prod_op_detenida					CHAR(1)					NOT NULL DEFAULT 'N'
	CONSTRAINT ckc_prod_op_detenida_prod_ord CHECK (prod_op_detenida IN ('N','S')),
	prod_op_num_emp_alta			NUMERIC(7,0)		NOT NULL,
	prod_op_fecha_alta				DATETIME			NOT NULL,
	prod_op_num_emp_bajamodif	NUMERIC(7,0)		NULL,
	prod_op_fecha_bajamodif		DATETIME			NULL,
	prod_op_id_estado					SMALLINT			NOT NULL,
	prod_op_observaciones			CHAR(250)				NULL,
	CONSTRAINT pk_prod_orden_prod PRIMARY KEY (prod_op_folio)
)
GO

CREATE TABLE prod_plan_prod
(
	prod_pp_periodo						CHAR(6)			NOT NULL,
	prod_pp_cve_prod_final			CHAR(15)			NOT NULL,
	prod_pp_dia_01						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_02						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_03						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_04						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_05						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_06						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_07						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_08						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_09						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_10						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_11						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_12						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_13						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_14						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_15						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_16						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_17						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_18						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_19						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_20						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_21						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_22						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_23						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_24						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_25						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_26						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_27						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_28						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_29						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_30						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pp_dia_31						DECIMAL(11,3)	NOT NULL DEFAULT 0,
	CONSTRAINT pk_prod_plan_prod PRIMARY KEY (prod_pp_cve_prod_final, prod_pp_periodo)
)
GO

CREATE TABLE prod_procfas_orden_prod
(
	prod_pfop_op_folio			NUMERIC(7,0)	NOT NULL,
	prod_pfop_as_folio				NUMERIC(7,0)	NOT NULL,
	prod_pfop_id_proc				NUMERIC(7,0)	NOT NULL,
	prod_pfop_orden				NUMERIC(7,0)	NOT NULL,
	prod_pfop_id_fase				NUMERIC(7,0)	NOT NULL,
	prod_pfop_incluir				CHAR(1)				NOT NULL DEFAULT 'S'
	CONSTRAINT ckc_prod_pfop_incluir_prod_pro CHECK (prod_pfop_incluir IN ('S','N')),
	prod_pfop_num_emp			NUMERIC(7,0)	NOT NULL,
	prod_pfop_fecha				DATETIME		NOT NULL,
	prod_pfop_observaciones		CHAR(250)			NULL,
	CONSTRAINT pk_prod_procfas_orden_prod PRIMARY KEY (prod_pfop_op_folio, prod_pfop_as_folio)
)
GO

CREATE TABLE prod_prod_diaria
(
	prod_pd_periodo				CHAR(6)			NOT NULL,
	prod_pd_cve_prod_final	CHAR(15)			NOT NULL,
	prod_pd_dia_01				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_02				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_03				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_04				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_05				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_06				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_07				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_08				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_09				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_10				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_11				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_12				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_13				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_14				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_15				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_16				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_17				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_18				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_19				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_20				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_21				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_22				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_23				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_24				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_25				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_26				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_27				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_28				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_29				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_30				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	prod_pd_dia_31				DECIMAL(11,3)	NOT NULL DEFAULT 0,
	CONSTRAINT pk_prod_prod_diaria PRIMARY KEY (prod_pd_periodo, prod_pd_cve_prod_final)
)
GO

CREATE TABLE prod_prod_terminados
(
	prod_pt_op_folio			NUMERIC(7,0)	NOT NULL,
	prod_pt_consecutivo		NUMERIC(7,0)	NOT NULL,
	prod_pt_cve_prod_final	CHAR(15)			NOT NULL,
	prod_pt_num_serie			CHAR(50)			NOT NULL DEFAULT 'S/N',
	prod_pt_num_parte			CHAR(50)			NULL,
	prod_pt_num_emp			NUMERIC(7,0)	NOT NULL,
	prod_pt_fecha				DATETIME		NOT NULL,
	prod_pt_observaciones	CHAR(250)			NULL,
	CONSTRAINT pk_prod_prod_terminados PRIMARY KEY (prod_pt_op_folio, prod_pt_consecutivo)
)
GO

CREATE TABLE prod_tiempos_muertos
(
	prod_tm_op_folio			NUMERIC(7,0)	NOT NULL,
	prod_tm_tm_folio			NUMERIC(7,0)	NOT NULL,
	prod_tm_fecha				DATETIME		NOT NULL,
	prod_tm_id_turno			SMALLINT		NOT NULL,
	prod_tm_id_motivo			NUMERIC(7,0)	NOT NULL,
	prod_tm_num_emp_ini		NUMERIC(7,0)	NOT NULL,
	prod_tm_fechor_ini		DATETIME		NOT NULL,
	prod_tm_num_emp_conc	NUMERIC(7,0)	NULL,
	prod_tm_fechor_conc		DATETIME		NULL,
	prod_tm_status				CHAR(1)				NOT NULL DEFAULT 'H'
	CONSTRAINT ckc_prod_tm_status_prod_tie CHECK (prod_tm_status IN ('H','D')),
	prod_tm_observaciones	CHAR(250)			NULL,
	CONSTRAINT pk_prod_tiempos_muertos PRIMARY KEY (prod_tm_op_folio, prod_tm_tm_folio)
)
GO

ALTER TABLE prod_art_vs_proceso
	ADD CONSTRAINT fk_prod_art_vs_proceso_01 FOREIGN KEY (prod_avsp_cve_art)
	REFERENCES cat_articulos (art_cve_art)
GO

ALTER TABLE prod_art_vs_proceso
	ADD CONSTRAINT fk_prod_art_vs_proceso_02 FOREIGN KEY (prod_avsp_id_unidad)
	REFERENCES prod_cat_unidades_medida (prod_cat_um_id_unidad)
GO

ALTER TABLE prod_art_vs_proceso
	ADD CONSTRAINT fk_prod_bit_cambio_materiales_03 FOREIGN KEY (prod_avsp_id_proc)
	REFERENCES prod_cat_proc_prod (prod_cat_pp_id_proc)
GO

ALTER TABLE prod_avance_orden_prod
	ADD CONSTRAINT fk_prod_avance_orden_prod_01 FOREIGN KEY (prod_aop_op_folio, prod_aop_as_folio)
	REFERENCES prod_procfas_orden_prod (prod_pfop_op_folio, prod_pfop_as_folio)
GO

ALTER TABLE prod_bit_orden_prod
	ADD CONSTRAINT fk_prod_bit_orden_prod_01 FOREIGN KEY (prod_bop_op_folio)
	REFERENCES prod_orden_prod (prod_op_folio)
GO

ALTER TABLE prod_bit_orden_prod
	ADD CONSTRAINT fk_prod_bit_orden_prod_02 FOREIGN KEY (prod_bop_id_estado)
	REFERENCES prod_cat_estados_op (prod_cat_eop_id_status)
GO

ALTER TABLE prod_bit_plan_prod
	ADD CONSTRAINT fk_prod_bit_plan_prod_01 FOREIGN KEY (prod_bpp_cve_prod_final, prod_bpp_periodo)
	REFERENCES prod_plan_prod (prod_pp_cve_prod_final, prod_pp_periodo)
GO

ALTER TABLE prod_depend_fases
	ADD CONSTRAINT fk_prod_depend_fases_01 FOREIGN KEY (prod_df_id_proc)
	REFERENCES prod_cat_proc_prod (prod_cat_pp_id_proc)
GO

ALTER TABLE prod_depend_fases
	ADD CONSTRAINT fk_prod_depend_fases_02 FOREIGN KEY (prod_df_id_fasey)
	REFERENCES prod_cat_fases_prod (prod_cat_fp_id_fase)
GO

ALTER TABLE prod_det_orden_prod
	ADD CONSTRAINT fk_prod_det_orden_prod_01 FOREIGN KEY (prod_dop_folio)
	REFERENCES prod_orden_prod (prod_op_folio)
GO

ALTER TABLE prod_mat_adic_orden_prod
	ADD CONSTRAINT fk_prod_mat_adic_orden_prod_01 FOREIGN KEY (prod_ma_op_folio)
	REFERENCES prod_orden_prod (prod_op_folio)
GO

ALTER TABLE prod_merma_orden_prod
	ADD CONSTRAINT fk_prod_merma_orden_prod_01 FOREIGN KEY (prod_mop_op_folio, prod_mop_as_folio)
	REFERENCES prod_avance_orden_prod (prod_aop_op_folio, prod_aop_as_folio)
GO

ALTER TABLE prod_orden_prod
	ADD CONSTRAINT fk_prod_orden_prod_02 FOREIGN KEY (prod_op_id_turno)
	REFERENCES prod_cat_turnos (prod_cat_t_id_turno)
GO

ALTER TABLE prod_orden_prod
	ADD CONSTRAINT fk_prod_orden_prod_03 FOREIGN KEY (prod_op_id_linea_ens)
	REFERENCES prod_cat_lineas_ensamble (prod_cat_le_id_linea_ens)
GO

ALTER TABLE prod_orden_prod
	ADD CONSTRAINT fk_prod_orden_prod_04 FOREIGN KEY (prod_op_tp_clave)
	REFERENCES prod_cat_tipos_prod (prod_cat_tp_clave)
GO

ALTER TABLE prod_orden_prod
	ADD CONSTRAINT fk_prod_orden_prod_05 FOREIGN KEY (prod_op_id_proc_prod)
	REFERENCES prod_cat_proc_prod (prod_cat_pp_id_proc)
GO

ALTER TABLE prod_orden_prod
	ADD CONSTRAINT fk_prod_orden_prod_06 FOREIGN KEY (prod_op_id_estado)
	REFERENCES prod_cat_estados_op (prod_cat_eop_id_status)
GO

ALTER TABLE prod_procfas_orden_prod
	ADD CONSTRAINT fk_prod_procfas_orden_prod_01 FOREIGN KEY (prod_pfop_op_folio)
	REFERENCES prod_orden_prod (prod_op_folio)
GO

ALTER TABLE prod_procfas_orden_prod
	ADD CONSTRAINT fk_prod_procfas_orden_prod_02 FOREIGN KEY (prod_pfop_id_proc)
	REFERENCES prod_cat_proc_prod (prod_cat_pp_id_proc)
GO

ALTER TABLE prod_procfas_orden_prod
	ADD CONSTRAINT fk_prod_procfas_orden_prod_03 FOREIGN KEY (prod_pfop_id_fase)
	REFERENCES prod_cat_fases_prod (prod_cat_fp_id_fase)
GO

ALTER TABLE prod_prod_terminados
	ADD CONSTRAINT fk_prod_prod_terminados_01 FOREIGN KEY (prod_pt_op_folio)
	REFERENCES prod_orden_prod (prod_op_folio)
GO

ALTER TABLE prod_tiempos_muertos
	ADD CONSTRAINT fk_prod_tiempos_muertos_01 FOREIGN KEY (prod_tm_op_folio)
	REFERENCES prod_orden_prod (prod_op_folio)
GO



ALTER TABLE prod_tiempos_muertos
	ADD CONSTRAINT fk_prod_tiempos_muertos_02 FOREIGN KEY (prod_tm_id_motivo)
	REFERENCES prod_cat_mot_tiempos_muertos (prod_cat_mtm_id_motivo)
GO

CREATE PROCEDURE sia_prod_planvsops ( @pc_periodo CHAR(6), @pi_dia TINYINT, @pdt_fecha DATETIME ) AS

DECLARE @lc_cveart CHAR(15), @lc_artdescrip CHAR(70), @ldec_cantplaneada DECIMAL(11,3), @ldec_cantenops DECIMAL(11,3), @li_mientras INTEGER

CREATE TABLE #temp_planvsops
(
	prod_cve_art		CHAR(15) NOT NULL,
	prod_artdescrip	CHAR(70) NOT NULL,
	prod_cant_plan	DECIMAL(11,3) DEFAULT 0 NOT NULL,
	prod_cant_enops	DECIMAL(11,3) DEFAULT 0 NOT NULL
)

DECLARE cur_prodplanvsops CURSOR FOR
	SELECT prod_pp_cve_prod_final,
	CASE
		WHEN @pi_dia = 1 THEN prod_pp_dia_01 WHEN @pi_dia = 2 THEN prod_pp_dia_02
		WHEN @pi_dia = 3 THEN prod_pp_dia_03 WHEN @pi_dia = 4 THEN prod_pp_dia_04
		WHEN @pi_dia = 5 THEN prod_pp_dia_05 WHEN @pi_dia = 6 THEN prod_pp_dia_06
		WHEN @pi_dia = 7 THEN prod_pp_dia_07 WHEN @pi_dia = 8 THEN prod_pp_dia_08
		WHEN @pi_dia = 9 THEN prod_pp_dia_09 WHEN @pi_dia = 10 THEN prod_pp_dia_10
		WHEN @pi_dia = 11 THEN prod_pp_dia_11 WHEN @pi_dia = 12 THEN prod_pp_dia_11
		WHEN @pi_dia = 13 THEN prod_pp_dia_13 WHEN @pi_dia = 14 THEN prod_pp_dia_14
		WHEN @pi_dia = 15 THEN prod_pp_dia_15 WHEN @pi_dia = 16 THEN prod_pp_dia_16
		WHEN @pi_dia = 17 THEN prod_pp_dia_17 WHEN @pi_dia = 18 THEN prod_pp_dia_18
		WHEN @pi_dia = 19 THEN prod_pp_dia_19 WHEN @pi_dia = 20 THEN prod_pp_dia_20
		WHEN @pi_dia = 21 THEN prod_pp_dia_21 WHEN @pi_dia = 22 THEN prod_pp_dia_22
		WHEN @pi_dia = 23 THEN prod_pp_dia_23 WHEN @pi_dia = 24 THEN prod_pp_dia_24
		WHEN @pi_dia = 25 THEN prod_pp_dia_25 WHEN @pi_dia = 26 THEN prod_pp_dia_26
		WHEN @pi_dia = 27 THEN prod_pp_dia_27 WHEN @pi_dia = 28 THEN prod_pp_dia_28
		WHEN @pi_dia = 29 THEN prod_pp_dia_29 WHEN @pi_dia = 30 THEN prod_pp_dia_30
		WHEN @pi_dia = 31 THEN prod_pp_dia_31
	END
	FROM prod_plan_prod
	WHERE prod_pp_periodo = @pc_periodo
FOR READ ONLY

SELECT @li_mientras = 0
OPEN cur_prodplanvsops
WHILE @li_mientras = 0
	BEGIN
		FETCH cur_prodplanvsops INTO @lc_cveart, @ldec_cantplaneada
		IF @@fetch_status = -1 BREAK
		SELECT @li_mientras = @@fetch_status

		IF @ldec_cantplaneada > 0
			BEGIN
				SELECT @ldec_cantenops = IsNull(sum(prod_op_cantidad), 0)
				FROM prod_orden_prod
				WHERE ( prod_op_origen_plan_prod = 'S' )
				AND ( prod_op_id_estado NOT IN (4,7) )
				AND ( prod_op_cve_prod_final = @lc_cveart )
				AND (CONVERT(CHAR(10), prod_op_fecha_prod, 103)) = CONVERT(CHAR(10), @pdt_fecha, 103)

				SELECT @lc_artdescrip = art_descripcion
				FROM cat_articulos  
				WHERE art_cve_art = @lc_cveart

				INSERT INTO #temp_planvsops
				( prod_cve_art, prod_artdescrip, prod_cant_plan, prod_cant_enops )
				VALUES ( @lc_cveart, @lc_artdescrip, @ldec_cantplaneada, @ldec_cantenops )
			END
	END
CLOSE cur_prodplanvsops
DEALLOCATE cur_prodplanvsops

SELECT prod_cve_art, prod_artdescrip, prod_cant_plan, prod_cant_enops
FROM #temp_planvsops
WHERE prod_cant_plan <> prod_cant_enops
ORDER BY prod_cve_art
RETURN
GO



CREATE TRIGGER prod_trig_upd_exp_materiales ON prod_exp_materiales FOR UPDATE AS

DECLARE @lc_estatus CHAR(1), @ln_id NUMERIC(7,0), @ln_totregsmat NUMERIC(7,0), @ln_delregsmat NUMERIC(7,0)

IF UPDATE(prod_em_status)
	BEGIN
		SELECT @lc_estatus = prod_em_status FROM inserted
		IF @lc_estatus = 'E'
			BEGIN
				INSERT INTO prod_bas_exp_materiales
				( prod_bem_cve_padre, prod_bem_cve_hijo, prod_bem_tipo_material, prod_bem_opcional_de,
				prod_bem_cantidad, prod_bem_id_unidad, prod_bem_importancia, prod_bem_num_emp_alta,
				prod_bem_fec_alta, prod_bem_num_emp_bajamodif, prod_bem_fec_bajamodif, prod_bem_status, prod_bem_observaciones )
				SELECT inserted.prod_em_cve_padre, inserted.prod_em_cve_hijo, inserted.prod_em_tipo_material, inserted.prod_em_opcional_de,
				inserted.prod_em_cantidad, inserted.prod_em_id_unidad, inserted.prod_em_importancia, inserted.prod_em_num_emp_alta,
				inserted.prod_em_fec_alta, inserted.prod_em_num_emp_bajamodif, inserted.prod_em_fec_bajamodif, inserted.prod_em_status, inserted.prod_em_observaciones  
				FROM inserted, deleted
				WHERE inserted.prod_em_cve_padre = deleted.prod_em_cve_padre
				AND inserted.prod_em_cve_hijo = deleted.prod_em_cve_hijo
				AND inserted.prod_em_opcional_de = deleted.prod_em_opcional_de

				SELECT @ln_totregsmat = @@rowcount

				IF @ln_totregsmat > 0
					INSERT INTO prod_bas_bit_cambio_materiales  
					( prod_bbc_id, prod_bbc_orig_id, prod_bbc_cve_padre, prod_bbc_cve_hijo, prod_bbc_cve_hijo_ant,   
					prod_bbc_tipo_material_ant, prod_bbc_cantidad_ant, prod_bbc_id_unidad_ant, prod_bbc_num_emp,   
					prod_bbc_fec, prod_bbc_observaciones )  
					SELECT @@identity, prod_bit_cambio_materiales.prod_bcc_id, prod_bit_cambio_materiales.prod_bcc_cve_padre,
					prod_bit_cambio_materiales.prod_bcc_cve_hijo, prod_bit_cambio_materiales.prod_bcc_cve_hijo_ant,   
					prod_bit_cambio_materiales.prd_bcc_tipo_material_ant, prod_bit_cambio_materiales.prod_bcc_cantidad_ant,
					prod_bit_cambio_materiales.prod_bcc_id_unidad_ant, prod_bit_cambio_materiales.prod_bcc_num_emp,   
					prod_bit_cambio_materiales.prod_bcc_fec, prod_bit_cambio_materiales.prod_bcc_observaciones
					FROM prod_bit_cambio_materiales, inserted, deleted
					WHERE prod_bit_cambio_materiales.prod_bcc_cve_padre = inserted.prod_em_cve_padre
					AND prod_bit_cambio_materiales.prod_bcc_cve_hijo = inserted.prod_em_cve_hijo
					AND prod_bit_cambio_materiales.prod_bcc_cve_padre = deleted.prod_em_cve_padre
					AND prod_bit_cambio_materiales.prod_bcc_cve_hijo = deleted.prod_em_cve_hijo
			
				IF @@error = 0 AND @ln_totregsmat > 0
					BEGIN
						DELETE prod_exp_materiales
						FROM prod_exp_materiales, inserted, deleted
						WHERE prod_exp_materiales.prod_em_cve_padre = inserted.prod_em_cve_padre
						AND prod_exp_materiales.prod_em_cve_hijo = inserted.prod_em_cve_hijo
						AND prod_exp_materiales.prod_em_opcional_de = inserted.prod_em_opcional_de
						AND inserted.prod_em_cve_padre = deleted.prod_em_cve_padre
						AND inserted.prod_em_cve_hijo = deleted.prod_em_cve_hijo
						AND inserted.prod_em_opcional_de = deleted.prod_em_opcional_de

						SELECT @ln_delregsmat = @@rowcount
						IF @ln_delregsmat > 0
							DELETE prod_bit_cambio_materiales
							FROM prod_bit_cambio_materiales, inserted, deleted
							WHERE prod_bit_cambio_materiales.prod_bcc_cve_padre = inserted.prod_em_cve_padre
							AND prod_bit_cambio_materiales.prod_bcc_cve_hijo = inserted.prod_em_cve_hijo
							AND prod_bit_cambio_materiales.prod_bcc_cve_padre = deleted.prod_em_cve_padre
							AND prod_bit_cambio_materiales.prod_bcc_cve_hijo = deleted.prod_em_cve_hijo
					END
			END
	END
GO